bbprep.Ensemble
===============

.. currentmodule:: bbprep

.. autoclass:: Ensemble
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Ensemble.add_conformer
      ~Ensemble.get_base_molecule
      ~Ensemble.get_molecule_num_atoms
      ~Ensemble.get_num_conformers
      ~Ensemble.yield_conformers
   
   

   
   
   